==> angular-validation-message-i18next-0.1.0.tgz: package/angular-validation-message-i18next.es5.js <==
import { Component, Inject, NgModule, Optional, ViewEncapsulation } from '@angular/core';
import { FormControlName, FormGroupName } from '@angular/forms';
import { I18NEXT_NAMESPACE, I18NextModule } from 'angular-i18next';
import { ValidationMessageComponent, ValidationMessageModule } from 'angular-validation-message';

var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var I18NextValidationMessageComponent = (function (_super) {
    __extends(I18NextValidationMessageComponent, _super);
    function I18NextValidationMessageComponent(i18nextNamespace, formControlName, formGroupName) {
        var _this = _super.call(this, formControlName, formGroupName) || this;
        _this.i18nextNamespace = i18nextNamespace;
        _this.formControlName = formControlName;
        _this.formGroupName = formGroupName;
        _this.VALIDATION = 'validation';
        return _this;
    }
    Object.defineProperty(I18NextValidationMessageComponent.prototype, "i18nextKey", {
        get: /**
         * @return {?}
         */
        function () {
            if (!this.firstMessage.key)
                return '';
            var /** @type {?} */ specificKey = [this.VALIDATION, ['control_specific', this.controlPath, this.firstMessage.key].join('.')].join(':');
            var /** @type {?} */ commonKey = [this.VALIDATION, this.firstMessage.key].join(':');
            var /** @type {?} */ i18nextKeys = [];
            if (this.i18nextNamespace && this.i18nextNamespace !== this.VALIDATION) {
                i18nextKeys.push([this.i18nextNamespace, specificKey].join('.'));
                i18nextKeys.push([this.i18nextNamespace, commonKey].join('.'));
            }
            i18nextKeys.push(specificKey);
            i18nextKeys.push(commonKey);
            return i18nextKeys;
        },
        enumerable: true,
        configurable: true
    });
    I18NextValidationMessageComponent.decorators = [
        { type: Component, args: [{
                    selector: 'i18next-validation-message',
                    template: "\n      <div class=\"error-container\">{{ i18nextKey | i18nextCap: firstMessage.params }}</div>\n    ",
                    styles: ["\n      i18next-validation-message {\n        display: none;\n        width: 100%;\n      }\n      i18next-validation-message.standalone,\n      .ng-dirty.ng-invalid + i18next-validation-message {\n        display: block;\n      }\n    "],
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    I18NextValidationMessageComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [I18NEXT_NAMESPACE,] },] },
        { type: FormControlName, decorators: [{ type: Optional },] },
        { type: FormGroupName, decorators: [{ type: Optional },] },
    ]; };
    return I18NextValidationMessageComponent;
}(ValidationMessageComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var declarations = [
    I18NextValidationMessageComponent,
];
var providers = [
    {
        provide: ValidationMessageComponent,
        useValue: I18NextValidationMessageComponent
    }
];
var I18NextValidationMessageModule = (function () {
    function I18NextValidationMessageModule() {
    }
    I18NextValidationMessageModule.decorators = [
        { type: NgModule, args: [{
                    declarations: declarations,
                    exports: declarations,
                    entryComponents: declarations,
                    imports: [
                        I18NextModule,
                        ValidationMessageModule
                    ],
                    providers: providers
                },] },
    ];
    /** @nocollapse */
    I18NextValidationMessageModule.ctorParameters = function () { return []; };
    return I18NextValidationMessageModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { I18NextValidationMessageComponent, declarations, providers, I18NextValidationMessageModule };

==> angular-validation-message-i18next-1.0.0.tgz: package/angular-validation-message-i18next.es5.js <==
import { Component, Inject, NgModule, Optional, ViewEncapsulation } from '@angular/core';
import { FormControlName, FormGroupName } from '@angular/forms';
import { I18NEXT_NAMESPACE, I18NextModule } from 'angular-i18next';
import { ValidationMessageComponent, ValidationMessageModule } from 'angular-validation-message';

var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var I18NextValidationMessageComponent = (function (_super) {
    __extends(I18NextValidationMessageComponent, _super);
    function I18NextValidationMessageComponent(i18nextNamespace, formControlName, formGroupName) {
        var _this = _super.call(this, formControlName, formGroupName) || this;
        _this.i18nextNamespace = i18nextNamespace;
        _this.formControlName = formControlName;
        _this.formGroupName = formGroupName;
        _this.VALIDATION = 'validation';
        return _this;
    }
    Object.defineProperty(I18NextValidationMessageComponent.prototype, "i18nextKey", {
        get: /**
         * @return {?}
         */
        function () {
            if (!this.firstMessage.key)
                return '';
            var /** @type {?} */ specificKey = [this.VALIDATION, ['control_specific', this.controlPath, this.firstMessage.key].join('.')].join(':');
            var /** @type {?} */ commonKey = [this.VALIDATION, this.firstMessage.key].join(':');
            var /** @type {?} */ i18nextKeys = [];
            if (this.i18nextNamespace && this.i18nextNamespace !== this.VALIDATION) {
                i18nextKeys.push([this.i18nextNamespace, specificKey].join('.'));
                i18nextKeys.push([this.i18nextNamespace, commonKey].join('.'));
            }
            i18nextKeys.push(specificKey);
            i18nextKeys.push(commonKey);
            return i18nextKeys;
        },
        enumerable: true,
        configurable: true
    });
    I18NextValidationMessageComponent.decorators = [
        { type: Component, args: [{
                    selector: 'i18next-validation-message',
                    template: "\n      <div class=\"error-container\">{{ i18nextKey | i18nextCap: firstMessage.params }}</div>\n    ",
                    styles: ["\n      i18next-validation-message {\n        display: none;\n        width: 100%;\n        position: relative;\n      }\n      i18next-validation-message.standalone,\n      .ng-dirty.ng-invalid + i18next-validation-message {\n        display: block;\n      }\n    "],
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    I18NextValidationMessageComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [I18NEXT_NAMESPACE,] },] },
        { type: FormControlName, decorators: [{ type: Optional },] },
        { type: FormGroupName, decorators: [{ type: Optional },] },
    ]; };
    return I18NextValidationMessageComponent;
}(ValidationMessageComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var declarations = [
    I18NextValidationMessageComponent,
];
var providers = [
    {
        provide: ValidationMessageComponent,
        useValue: I18NextValidationMessageComponent
    }
];
var I18NextValidationMessageModule = (function () {
    function I18NextValidationMessageModule() {
    }
    I18NextValidationMessageModule.decorators = [
        { type: NgModule, args: [{
                    declarations: declarations,
                    exports: declarations,
                    entryComponents: declarations,
                    imports: [
                        I18NextModule,
                        ValidationMessageModule
                    ],
                    providers: providers
                },] },
    ];
    /** @nocollapse */
    I18NextValidationMessageModule.ctorParameters = function () { return []; };
    return I18NextValidationMessageModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { I18NextValidationMessageComponent, declarations, providers, I18NextValidationMessageModule };
